@@ -5,7 +5,7 @@ package DataFlow::Node::Dumper;
 use strict;
 use warnings;
 
-our $VERSION = '0.91.05';    # VERSION
+our $VERSION = '0.91.06';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -15,9 +15,8 @@ use Data::Dumper;
 has '+process_item' => (
     default => sub {
         return sub {
-            shift;
-            my $item = shift;
-            print STDERR Dumper($item);
+            my ( $self, $item ) = @_;
+            $self->raw_dumper($item);
             return $item;
           }
     }
@@ -35,7 +34,7 @@ DataFlow::Node::Dumper - A debugging node that will dump data to STDERR
 
 =head1 VERSION
 
-version 0.91.05
+version 0.91.06
 
 =head1 SYNOPSIS
 
